=== modified file 'Makefile'
--- Makefile	2009-01-10 05:41:16 +0000
+++ Makefile	2009-01-10 00:53:09 +0000
@@ -77,7 +77,7 @@
 PLUGINS=plugins.d/password-prompt plugins.d/mandos-client \
 	plugins.d/usplash plugins.d/splashy plugins.d/askpass-fifo
 CPROGS=plugin-runner $(PLUGINS)
-PROGS=mandos mandos-keygen $(CPROGS)
+PROGS=mandos mandos-keygen mandos-list $(CPROGS)
 DOCS=mandos.8 plugin-runner.8mandos mandos-keygen.8 \
 	plugins.d/mandos-client.8mandos \
 	plugins.d/password-prompt.8mandos mandos.conf.5 \
@@ -164,6 +164,11 @@
 		--expression='s/^\(VERSION="\)[^"]*"$$/\1$(version)"/' \
 		$@
 
+mandos-list: Makefile
+	$(SED) --in-place \
+		--expression='s/^\(version = "\)[^"]*"$$/\1$(version)"/' \
+		$@
+
 mandos.lsm: Makefile
 	$(SED) --in-place \
 		--expression='s/^\(Version:\).*/\1\t$(version)/' \
@@ -198,8 +203,7 @@
 run-client: all keydir/seckey.txt keydir/pubkey.txt
 	./plugin-runner --plugin-dir=plugins.d \
 		--config-file=plugin-runner.conf \
-		--options-for=mandos-client:--seckey=keydir/seckey.txt,--pubkey=keydir/pubkey.txt \
-		$(CLIENTARGS)
+		--options-for=mandos-client:--seckey=keydir/seckey.txt,--pubkey=keydir/pubkey.txt
 
 # Used by run-client
 keydir/seckey.txt keydir/pubkey.txt: mandos-keygen
@@ -208,7 +212,7 @@
 
 # Run the server with a local config
 run-server: confdir/mandos.conf confdir/clients.conf
-	./mandos --debug --configdir=confdir $(SERVERARGS)
+	./mandos --debug --configdir=confdir
 
 # Used by run-server
 confdir/mandos.conf: mandos.conf

=== modified file 'mandos'
--- mandos	2009-01-10 05:41:16 +0000
+++ mandos	2009-01-08 03:54:06 +0000
@@ -35,7 +35,7 @@
 
 import SocketServer
 import socket
-import optparse
+from optparse import OptionParser
 import datetime
 import errno
 import gnutls.crypto
@@ -889,7 +889,7 @@
 
 
 def main():
-    parser = optparse.OptionParser(version = "%%prog %s" % version)
+    parser = OptionParser(version = "%%prog %s" % version)
     parser.add_option("-i", "--interface", type="string",
                       metavar="IF", help="Bind to interface IF")
     parser.add_option("-a", "--address", type="string",
@@ -911,7 +911,8 @@
                       " files")
     parser.add_option("--no-dbus", action="store_false",
                       dest="use_dbus",
-                      help=optparse.SUPPRESS_HELP)
+                      help="Do not provide D-Bus system bus"
+                      " interface")
     options = parser.parse_args()[0]
     
     if options.check:
@@ -957,7 +958,6 @@
     # For convenience
     debug = server_settings["debug"]
     use_dbus = server_settings["use_dbus"]
-    use_dbus = False
     
     if not debug:
         syslogger.setLevel(logging.WARNING)

=== added file 'mandos-list'
--- mandos-list	1970-01-01 00:00:00 +0000
+++ mandos-list	2008-12-21 19:19:25 +0000
@@ -0,0 +1,65 @@
+#!/usr/bin/python
+# -*- mode: python; coding: utf-8 -*-
+
+import dbus
+from optparse import OptionParser
+import locale
+
+locale.setlocale(locale.LC_ALL, u'')
+
+tablewords = {
+    'name': u'Name',
+    'enabled': u'Enabled',
+    'timeout': u'Timeout',
+    'last_checked_ok': u'Last Successful Check',
+    'created': u'Created',
+    'interval': u'Interval',
+    'host': u'Host',
+    'fingerprint': u'Fingerprint',
+    'checker_running': u'Check Is Running',
+    'last_enabled': u'Last Enabled',
+    'checker': u'Checker',
+    }
+busname = 'org.mandos-system.Mandos'
+object_path = '/Mandos'
+interface = 'org.mandos_system.Mandos'
+version = "1.0.2"
+defaultkeywords = ('name', 'enabled', 'timeout', 'last_checked_ok',
+                   'checker')
+
+parser = OptionParser(version = "%%prog %s" % version)
+parser.add_option("-a", "--all", action="store_true", default=False,
+                  help="Print all fields")
+options = parser.parse_args()[0]
+if options.all:
+    keywords = ('name', 'enabled', 'timeout', 'last_checked_ok',
+                'created', 'interval', 'host', 'fingerprint',
+                'checker_running', 'last_enabled', 'checker')
+else:
+    keywords = defaultkeywords
+
+
+bus = dbus.SystemBus()
+mandos_dbus_objc = bus.get_object(busname, object_path)
+mandos_serv = dbus.Interface(mandos_dbus_objc,
+                             dbus_interface = interface)
+mandos_clients = mandos_serv.GetAllClientsWithProperties()
+
+def valuetostring(x):
+    if type(x) is dbus.Boolean:
+        return u"Yes" if x else u"No"
+    else:
+        return unicode(x)
+
+format_string = u' '.join(u'%%-%ds'
+                         % max(len(tablewords[key]),
+                               max(len(valuetostring(client[key]))
+                                   for client
+                                   in mandos_clients.itervalues()))
+                         for key in keywords)
+print format_string % tuple(tablewords[key] for key in keywords) 
+for client in mandos_clients.itervalues():
+    print format_string % tuple(valuetostring(client[key])
+                                for key in keywords)
+
+

=== modified file 'mandos.xml'
--- mandos.xml	2009-01-05 23:26:06 +0000
+++ mandos.xml	2009-01-04 21:54:55 +0000
@@ -85,6 +85,8 @@
       <replaceable>DIRECTORY</replaceable></option></arg>
       <sbr/>
       <arg><option>--debug</option></arg>
+      <sbr/>
+      <arg><option>--no-dbus</option></arg>
     </cmdsynopsis>
     <cmdsynopsis>
       <command>&COMMANDNAME;</command>
@@ -229,6 +231,16 @@
 	  </para>
 	</listitem>
       </varlistentry>
+      
+      <varlistentry>
+	<term><option>--no-dbus</option></term>
+	<listitem>
+	  <xi:include href="mandos-options.xml" xpointer="dbus"/>
+	  <para>
+	    See also <xref linkend="dbus_interface"/>.
+	  </para>
+	</listitem>
+      </varlistentry>
     </variablelist>
   </refsect1>
   
@@ -324,6 +336,16 @@
     </para>
   </refsect1>
   
+  <refsect1 id="dbus_interface">
+    <title>D-BUS INTERFACE</title>
+    <para>
+      The server will by default provide a D-Bus system bus interface.
+      This interface will only be accessible by the root user or a
+      Mandos-specific user, if such a user exists.
+      <!-- XXX -->
+    </para>
+  </refsect1>
+
   <refsect1 id="exit_status">
     <title>EXIT STATUS</title>
     <para>

=== modified file 'plugins.d/askpass-fifo.c'
--- plugins.d/askpass-fifo.c	2009-01-10 02:21:13 +0000
+++ plugins.d/askpass-fifo.c	2009-01-04 21:54:55 +0000
@@ -43,14 +43,14 @@
   
   /* Create FIFO */
   const char passfifo[] = "/lib/cryptsetup/passfifo";
-  ret = (int)TEMP_FAILURE_RETRY(mkfifo(passfifo, S_IRUSR | S_IWUSR));
+  ret = TEMP_FAILURE_RETRY(mkfifo(passfifo, S_IRUSR | S_IWUSR));
   if(ret == -1 and errno != EEXIST){
     perror("mkfifo");
     return EXIT_FAILURE;
   }
   
   /* Open FIFO */
-  int fifo_fd = (int)TEMP_FAILURE_RETRY(open(passfifo, O_RDONLY));
+  int fifo_fd = TEMP_FAILURE_RETRY(open(passfifo, O_RDONLY));
   if(fifo_fd == -1){
     perror("open");
     return EXIT_FAILURE;

=== modified file 'plugins.d/mandos-client.c'
--- plugins.d/mandos-client.c	2009-01-10 02:21:13 +0000
+++ plugins.d/mandos-client.c	2009-01-04 21:54:55 +0000
@@ -156,7 +156,7 @@
     int fd;
     gpgme_data_t pgp_data;
     
-    fd = (int)TEMP_FAILURE_RETRY(open(filename, O_RDONLY));
+    fd = TEMP_FAILURE_RETRY(open(filename, O_RDONLY));
     if(fd == -1){
       perror("open");
       return false;
@@ -176,7 +176,7 @@
       return false;
     }
     
-    ret = (int)TEMP_FAILURE_RETRY(close(fd));
+    ret = TEMP_FAILURE_RETRY(close(fd));
     if(ret == -1){
       perror("close");
     }
@@ -501,7 +501,6 @@
 				      AvahiIfIndex if_index,
 				      mandos_context *mc){
   int ret, tcp_sd;
-  ssize_t sret;
   union { struct sockaddr in; struct sockaddr_in6 in6; } to;
   char *buffer = NULL;
   char *decrypted_buffer;
@@ -578,7 +577,7 @@
   written = 0;
   while (true){
     size_t out_size = strlen(out);
-    ret = (int)TEMP_FAILURE_RETRY(write(tcp_sd, out + written,
+    ret = TEMP_FAILURE_RETRY(write(tcp_sd, out + written,
 				   out_size - written));
     if (ret == -1){
       perror("write");
@@ -633,13 +632,13 @@
       goto mandos_end;
     }
     
-    sret = gnutls_record_recv(session, buffer+buffer_length,
-			      BUFFER_SIZE);
-    if (sret == 0){
+    ret = gnutls_record_recv(session, buffer+buffer_length,
+			     BUFFER_SIZE);
+    if (ret == 0){
       break;
     }
-    if (sret < 0){
-      switch(sret){
+    if (ret < 0){
+      switch(ret){
       case GNUTLS_E_INTERRUPTED:
       case GNUTLS_E_AGAIN:
 	break;
@@ -662,7 +661,7 @@
 	goto mandos_end;
       }
     } else {
-      buffer_length += (size_t) sret;
+      buffer_length += (size_t) ret;
     }
   }
   
@@ -704,7 +703,7 @@
   
  mandos_end:
   free(buffer);
-  ret = (int)TEMP_FAILURE_RETRY(close(tcp_sd));
+  ret = TEMP_FAILURE_RETRY(close(tcp_sd));
   if(ret == -1){
     perror("close");
   }
@@ -941,7 +940,7 @@
 	  goto end;
 	}
       }
-      ret = (int)TEMP_FAILURE_RETRY(close(sd));
+      ret = TEMP_FAILURE_RETRY(close(sd));
       if(ret == -1){
 	perror("close");
       }

=== modified file 'plugins.d/usplash.c'
--- plugins.d/usplash.c	2009-01-10 02:21:13 +0000
+++ plugins.d/usplash.c	2009-01-04 21:54:55 +0000
@@ -92,11 +92,10 @@
   }
   
   size_t written = 0;
-  ssize_t sret = 0;
   while(not interrupted_by_signal and written < cmd_line_len){
-    sret = write(fifo_fd, cmd_line + written,
-		 cmd_line_len - written);
-    if(sret == -1){
+    ret = write(fifo_fd, cmd_line + written,
+		cmd_line_len - written);
+    if(ret == -1){
       if(errno != EINTR or interrupted_by_signal){
 	int e = errno;
 	close(fifo_fd);
@@ -107,7 +106,7 @@
 	continue;
       }
     }
-    written += (size_t)sret;
+    written += (size_t)ret;
   }
   free(cmd_line_alloc);
   do{

